@@ -6,7 +6,7 @@ use v5.10;
 
 use Moo 1;
 
-use List::Util qw/ first none /;
+use List::Util 1.33 qw/ first none /;
 use Net::DNS::Resolver;
 use Types::Standard -types;
 
@@ -15,7 +15,7 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 
 has resolver => (
@@ -73,7 +73,7 @@ sub _build_robots {
         {
             name   => "Yandex",
             agent  => qr/Yandex/,
-            domain => qr/\.spider\.yandex\.com$/,
+            domain => qr/\.yandex\.(?:com|ru|net)$/,
         },
     ];
 }
@@ -141,6 +141,7 @@ sub validate {
     return;
 }
 
+
 1;
 
 __END__
@@ -155,7 +156,7 @@ Robots::Validate - validate IP addresses are associated with known robots
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
@@ -230,6 +231,18 @@ It is optional.
 
 =back
 
+=head1 SEE ALSO
+
+=over
+
+=item L<Verifying Bingbot|https://www.bing.com/webmaster/help/how-to-verify-bingbot-3905dc26>
+
+=item L<Verifying Goodlebot|https://support.google.com/webmasters/answer/80553>
+
+=item L<How to check that a robot belongs to Yandex|https://yandex.com/support/webmaster/robot-workings/check-yandex-robots.html>
+
+=back
+
 =head1 SOURCE
 
 The development version is on github at L<https://github.com/robrwo/Robots-Validate>
